@@ -10,6 +10,7 @@ else:
 
 import scipy.stats as sps
 import numpy as np
+import itertools
 
 dists = {
     'alpha' : sps.alpha,
@@ -128,34 +129,13 @@ dists = {
     'yulesimon' : sps.yulesimon
 }
 
-def __get_bounds(function_name = None,steps = 200,*args):
+def __get_bounds(function_name = None,steps = Pbox.STEPS,*args):
 
+    # define support
     x = np.linspace(0.0001,0.9999,steps)
 
-    arg_list = [list(args)]
-    complete = False
-    # while not complete:
-    for i in arg_list:
-        for j in range(len(i)):
-            if i[j].__class__.__name__ == 'Interval':
-
-                k1 = [i[j].left() if l == i[j] else l for l in i]
-                k2 = [i[j].right() if l == i[j] else l for l in i]
-
-                arg_list.append(k1)
-                arg_list.append(k2)
-
-    new_args = []
-    for k in arg_list:
-        to_delete = False
-
-        for l in k:
-
-            if l.__class__.__name__ == 'Interval':
-                to_delete = True
-
-        if not to_delete and k not in new_args:
-            new_args.append(k)
+    #get bound arguments
+    new_args = itertools.product(*args)
 
     bounds = []
 
@@ -191,7 +171,7 @@ def __get_bounds(function_name = None,steps = 200,*args):
     return Left, Right, mean, var
 
 
-def lognormal(mean, var, steps = 200):
+def lognormal(mean, var, steps = Pbox.STEPS):
 
     x = np.linspace(0,1,steps)
 
@@ -214,14 +194,14 @@ def lognormal(mean, var, steps = 200):
         Left,
         Right,
         steps = steps,
-        shape='normal',
+        shape='lognormal',
         mean_left=mean.left(),
         mean_right=mean.right(),
         var_left=var.left(),
         var_right=var.right())
 lognorm = lognormal
 
-def alpha(*args, steps = 200):
+def alpha(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -240,7 +220,7 @@ def alpha(*args, steps = 200):
           var_right  = var.right()
           )
 
-def anglit(*args, steps = 200):
+def anglit(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -259,7 +239,7 @@ def anglit(*args, steps = 200):
           var_right  = var.right()
           )
 
-def arcsine(*args, steps = 200):
+def arcsine(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -278,7 +258,7 @@ def arcsine(*args, steps = 200):
           var_right  = var.right()
           )
 
-def argus(*args, steps = 200):
+def argus(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -297,7 +277,7 @@ def argus(*args, steps = 200):
           var_right  = var.right()
           )
 
-def beta(*args, steps = 200):
+def beta(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -316,7 +296,7 @@ def beta(*args, steps = 200):
           var_right  = var.right()
           )
 
-def betaprime(*args, steps = 200):
+def betaprime(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -335,7 +315,7 @@ def betaprime(*args, steps = 200):
           var_right  = var.right()
           )
 
-def bradford(*args, steps = 200):
+def bradford(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -354,7 +334,7 @@ def bradford(*args, steps = 200):
           var_right  = var.right()
           )
 
-def burr(*args, steps = 200):
+def burr(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -373,7 +353,7 @@ def burr(*args, steps = 200):
           var_right  = var.right()
           )
 
-def burr12(*args, steps = 200):
+def burr12(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -392,7 +372,7 @@ def burr12(*args, steps = 200):
           var_right  = var.right()
           )
 
-def cauchy(*args, steps = 200):
+def cauchy(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -411,7 +391,7 @@ def cauchy(*args, steps = 200):
           var_right  = var.right()
           )
 
-def chi(*args, steps = 200):
+def chi(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -430,7 +410,7 @@ def chi(*args, steps = 200):
           var_right  = var.right()
           )
 
-def chi2(*args, steps = 200):
+def chi2(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -449,7 +429,7 @@ def chi2(*args, steps = 200):
           var_right  = var.right()
           )
 
-def cosine(*args, steps = 200):
+def cosine(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -468,7 +448,7 @@ def cosine(*args, steps = 200):
           var_right  = var.right()
           )
 
-def crystalball(*args, steps = 200):
+def crystalball(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -487,7 +467,7 @@ def crystalball(*args, steps = 200):
           var_right  = var.right()
           )
 
-def dgamma(*args, steps = 200):
+def dgamma(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -506,7 +486,7 @@ def dgamma(*args, steps = 200):
           var_right  = var.right()
           )
 
-def dweibull(*args, steps = 200):
+def dweibull(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -525,7 +505,7 @@ def dweibull(*args, steps = 200):
           var_right  = var.right()
           )
 
-def erlang(*args, steps = 200):
+def erlang(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -544,7 +524,7 @@ def erlang(*args, steps = 200):
           var_right  = var.right()
           )
 
-def expon(*args, steps = 200):
+def expon(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -563,7 +543,7 @@ def expon(*args, steps = 200):
           var_right  = var.right()
           )
 
-def exponnorm(*args, steps = 200):
+def exponnorm(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -582,7 +562,7 @@ def exponnorm(*args, steps = 200):
           var_right  = var.right()
           )
 
-def exponweib(*args, steps = 200):
+def exponweib(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -601,7 +581,7 @@ def exponweib(*args, steps = 200):
           var_right  = var.right()
           )
 
-def exponpow(*args, steps = 200):
+def exponpow(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -620,7 +600,7 @@ def exponpow(*args, steps = 200):
           var_right  = var.right()
           )
 
-def f(*args, steps = 200):
+def f(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -639,7 +619,7 @@ def f(*args, steps = 200):
           var_right  = var.right()
           )
 
-def fatiguelife(*args, steps = 200):
+def fatiguelife(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -658,7 +638,7 @@ def fatiguelife(*args, steps = 200):
           var_right  = var.right()
           )
 
-def fisk(*args, steps = 200):
+def fisk(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -677,7 +657,7 @@ def fisk(*args, steps = 200):
           var_right  = var.right()
           )
 
-def foldcauchy(*args, steps = 200):
+def foldcauchy(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -696,7 +676,7 @@ def foldcauchy(*args, steps = 200):
           var_right  = var.right()
           )
 
-def foldnorm(mu,s, steps = 200):
+def foldnorm(mu,s, steps = Pbox.STEPS):
 
     x = np.linspace(0.0001,0.9999,steps)
     if mu.__class__.__name__ != 'Interval':
@@ -754,7 +734,7 @@ def foldnorm(mu,s, steps = 200):
           var_right  = var.right()
           )
 
-def frechet_r(*args, steps = 200):
+def frechet_r(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -773,7 +753,7 @@ def frechet_r(*args, steps = 200):
           var_right  = var.right()
           )
 
-def frechet_l(*args, steps = 200):
+def frechet_l(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -792,7 +772,7 @@ def frechet_l(*args, steps = 200):
           var_right  = var.right()
           )
 
-def genlogistic(*args, steps = 200):
+def genlogistic(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -811,7 +791,7 @@ def genlogistic(*args, steps = 200):
           var_right  = var.right()
           )
 
-def gennorm(*args, steps = 200):
+def gennorm(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -830,7 +810,7 @@ def gennorm(*args, steps = 200):
           var_right  = var.right()
           )
 
-def genpareto(*args, steps = 200):
+def genpareto(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -849,7 +829,7 @@ def genpareto(*args, steps = 200):
           var_right  = var.right()
           )
 
-def genexpon(*args, steps = 200):
+def genexpon(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -868,7 +848,7 @@ def genexpon(*args, steps = 200):
           var_right  = var.right()
           )
 
-def genextreme(*args, steps = 200):
+def genextreme(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -887,7 +867,7 @@ def genextreme(*args, steps = 200):
           var_right  = var.right()
           )
 
-def gausshyper(*args, steps = 200):
+def gausshyper(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -906,7 +886,7 @@ def gausshyper(*args, steps = 200):
           var_right  = var.right()
           )
 
-def gamma(*args, steps = 200):
+def gamma(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -925,7 +905,7 @@ def gamma(*args, steps = 200):
           var_right  = var.right()
           )
 
-def gengamma(*args, steps = 200):
+def gengamma(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -944,7 +924,7 @@ def gengamma(*args, steps = 200):
           var_right  = var.right()
           )
 
-def genhalflogistic(*args, steps = 200):
+def genhalflogistic(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -963,7 +943,7 @@ def genhalflogistic(*args, steps = 200):
           var_right  = var.right()
           )
 
-def geninvgauss(*args, steps = 200):
+def geninvgauss(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -982,7 +962,7 @@ def geninvgauss(*args, steps = 200):
           var_right  = var.right()
           )
 
-def gilbrat(*args, steps = 200):
+def gilbrat(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1001,7 +981,7 @@ def gilbrat(*args, steps = 200):
           var_right  = var.right()
           )
 
-def gompertz(*args, steps = 200):
+def gompertz(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1020,7 +1000,7 @@ def gompertz(*args, steps = 200):
           var_right  = var.right()
           )
 
-def gumbel_r(*args, steps = 200):
+def gumbel_r(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1039,7 +1019,7 @@ def gumbel_r(*args, steps = 200):
           var_right  = var.right()
           )
 
-def gumbel_l(*args, steps = 200):
+def gumbel_l(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1058,7 +1038,7 @@ def gumbel_l(*args, steps = 200):
           var_right  = var.right()
           )
 
-def halfcauchy(*args, steps = 200):
+def halfcauchy(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1077,7 +1057,7 @@ def halfcauchy(*args, steps = 200):
           var_right  = var.right()
           )
 
-def halflogistic(*args, steps = 200):
+def halflogistic(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1096,7 +1076,7 @@ def halflogistic(*args, steps = 200):
           var_right  = var.right()
           )
 
-def halfnorm(*args, steps = 200):
+def halfnorm(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1115,7 +1095,7 @@ def halfnorm(*args, steps = 200):
           var_right  = var.right()
           )
 
-def halfgennorm(*args, steps = 200):
+def halfgennorm(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1134,7 +1114,7 @@ def halfgennorm(*args, steps = 200):
           var_right  = var.right()
           )
 
-def hypsecant(*args, steps = 200):
+def hypsecant(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1153,7 +1133,7 @@ def hypsecant(*args, steps = 200):
           var_right  = var.right()
           )
 
-def invgamma(*args, steps = 200):
+def invgamma(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1172,7 +1152,7 @@ def invgamma(*args, steps = 200):
           var_right  = var.right()
           )
 
-def invgauss(*args, steps = 200):
+def invgauss(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1191,7 +1171,7 @@ def invgauss(*args, steps = 200):
           var_right  = var.right()
           )
 
-def invweibull(*args, steps = 200):
+def invweibull(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1210,7 +1190,7 @@ def invweibull(*args, steps = 200):
           var_right  = var.right()
           )
 
-def johnsonsb(*args, steps = 200):
+def johnsonsb(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1229,7 +1209,7 @@ def johnsonsb(*args, steps = 200):
           var_right  = var.right()
           )
 
-def johnsonsu(*args, steps = 200):
+def johnsonsu(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1248,7 +1228,7 @@ def johnsonsu(*args, steps = 200):
           var_right  = var.right()
           )
 
-def kappa4(*args, steps = 200):
+def kappa4(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1267,7 +1247,7 @@ def kappa4(*args, steps = 200):
           var_right  = var.right()
           )
 
-def kappa3(*args, steps = 200):
+def kappa3(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1286,7 +1266,7 @@ def kappa3(*args, steps = 200):
           var_right  = var.right()
           )
 
-def ksone(*args, steps = 200):
+def ksone(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1305,7 +1285,7 @@ def ksone(*args, steps = 200):
           var_right  = var.right()
           )
 
-def kstwobign(*args, steps = 200):
+def kstwobign(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1324,7 +1304,7 @@ def kstwobign(*args, steps = 200):
           var_right  = var.right()
           )
 
-def laplace(*args, steps = 200):
+def laplace(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1343,7 +1323,7 @@ def laplace(*args, steps = 200):
           var_right  = var.right()
           )
 
-def levy(*args, steps = 200):
+def levy(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1362,7 +1342,7 @@ def levy(*args, steps = 200):
           var_right  = var.right()
           )
 
-def levy_l(*args, steps = 200):
+def levy_l(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1381,7 +1361,7 @@ def levy_l(*args, steps = 200):
           var_right  = var.right()
           )
 
-def levy_stable(*args, steps = 200):
+def levy_stable(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1400,7 +1380,7 @@ def levy_stable(*args, steps = 200):
           var_right  = var.right()
           )
 
-def logistic(*args, steps = 200):
+def logistic(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1419,7 +1399,7 @@ def logistic(*args, steps = 200):
           var_right  = var.right()
           )
 
-def loggamma(*args, steps = 200):
+def loggamma(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1438,7 +1418,7 @@ def loggamma(*args, steps = 200):
           var_right  = var.right()
           )
 
-def loglaplace(*args, steps = 200):
+def loglaplace(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1457,7 +1437,7 @@ def loglaplace(*args, steps = 200):
           var_right  = var.right()
           )
 
-def lognorm(*args, steps = 200):
+def lognorm(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1476,7 +1456,7 @@ def lognorm(*args, steps = 200):
           var_right  = var.right()
           )
 
-def loguniform(*args, steps = 200):
+def loguniform(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1495,7 +1475,7 @@ def loguniform(*args, steps = 200):
           var_right  = var.right()
           )
 
-def lomax(*args, steps = 200):
+def lomax(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1514,7 +1494,7 @@ def lomax(*args, steps = 200):
           var_right  = var.right()
           )
 
-def maxwell(*args, steps = 200):
+def maxwell(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1533,7 +1513,7 @@ def maxwell(*args, steps = 200):
           var_right  = var.right()
           )
 
-def mielke(*args, steps = 200):
+def mielke(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1552,7 +1532,7 @@ def mielke(*args, steps = 200):
           var_right  = var.right()
           )
 
-def moyal(*args, steps = 200):
+def moyal(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1571,7 +1551,7 @@ def moyal(*args, steps = 200):
           var_right  = var.right()
           )
 
-def nakagami(*args, steps = 200):
+def nakagami(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1590,7 +1570,7 @@ def nakagami(*args, steps = 200):
           var_right  = var.right()
           )
 
-def ncx2(*args, steps = 200):
+def ncx2(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1609,7 +1589,7 @@ def ncx2(*args, steps = 200):
           var_right  = var.right()
           )
 
-def ncf(*args, steps = 200):
+def ncf(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1628,7 +1608,7 @@ def ncf(*args, steps = 200):
           var_right  = var.right()
           )
 
-def nct(*args, steps = 200):
+def nct(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1647,12 +1627,14 @@ def nct(*args, steps = 200):
           var_right  = var.right()
           )
 
-def norm(*args, steps = 200):
+def norm(*args,steps=None):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
             args[i] = Interval(args[i])
 
+    if steps is None: steps  = Pbox.STEPS
+
     Left, Right, mean, var = __get_bounds('norm',steps,*args)
 
     return Pbox(
@@ -1666,7 +1648,7 @@ def norm(*args, steps = 200):
           var_right  = var.right()
           )
 
-def norminvgauss(*args, steps = 200):
+def norminvgauss(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1685,7 +1667,7 @@ def norminvgauss(*args, steps = 200):
           var_right  = var.right()
           )
 
-def pareto(*args, steps = 200):
+def pareto(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1704,7 +1686,7 @@ def pareto(*args, steps = 200):
           var_right  = var.right()
           )
 
-def pearson3(*args, steps = 200):
+def pearson3(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1723,7 +1705,7 @@ def pearson3(*args, steps = 200):
           var_right  = var.right()
           )
 
-def powerlaw(*args, steps = 200):
+def powerlaw(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1742,7 +1724,7 @@ def powerlaw(*args, steps = 200):
           var_right  = var.right()
           )
 
-def powerlognorm(*args, steps = 200):
+def powerlognorm(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1761,7 +1743,7 @@ def powerlognorm(*args, steps = 200):
           var_right  = var.right()
           )
 
-def powernorm(*args, steps = 200):
+def powernorm(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1780,7 +1762,7 @@ def powernorm(*args, steps = 200):
           var_right  = var.right()
           )
 
-def rdist(*args, steps = 200):
+def rdist(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1799,7 +1781,7 @@ def rdist(*args, steps = 200):
           var_right  = var.right()
           )
 
-def rayleigh(*args, steps = 200):
+def rayleigh(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1818,7 +1800,7 @@ def rayleigh(*args, steps = 200):
           var_right  = var.right()
           )
 
-def rice(*args, steps = 200):
+def rice(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1837,7 +1819,7 @@ def rice(*args, steps = 200):
           var_right  = var.right()
           )
 
-def recipinvgauss(*args, steps = 200):
+def recipinvgauss(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1856,7 +1838,7 @@ def recipinvgauss(*args, steps = 200):
           var_right  = var.right()
           )
 
-def semicircular(*args, steps = 200):
+def semicircular(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1875,7 +1857,7 @@ def semicircular(*args, steps = 200):
           var_right  = var.right()
           )
 
-def skewnorm(*args, steps = 200):
+def skewnorm(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1894,7 +1876,7 @@ def skewnorm(*args, steps = 200):
           var_right  = var.right()
           )
 
-def t(*args, steps = 200):
+def t(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1913,7 +1895,7 @@ def t(*args, steps = 200):
           var_right  = var.right()
           )
 
-def trapz(a,b,c,d , steps = 200):
+def trapz(a,b,c,d , steps = Pbox.STEPS):
     if a.__class__.__name__ != 'Interval':
         a = Interval(a)
     if b.__class__.__name__ != 'Interval':
@@ -1934,7 +1916,7 @@ def trapz(a,b,c,d , steps = 200):
           shape      = 'trapz'
           )
 
-def triang(*args, steps = 200):
+def triang(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1953,7 +1935,7 @@ def triang(*args, steps = 200):
           var_right  = var.right()
           )
 
-def truncexpon(*args, steps = 200):
+def truncexpon(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1972,7 +1954,7 @@ def truncexpon(*args, steps = 200):
           var_right  = var.right()
           )
 
-def truncnorm(*args, steps = 200):
+def truncnorm(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -1991,7 +1973,7 @@ def truncnorm(*args, steps = 200):
           var_right  = var.right()
           )
 
-def tukeylambda(*args, steps = 200):
+def tukeylambda(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -2011,7 +1993,7 @@ def tukeylambda(*args, steps = 200):
           )
 
 
-def uniform(a, b, steps = 200):
+def uniform(a, b, steps = Pbox.STEPS):
 
     x = np.linspace(0,1,steps)
 
@@ -2037,7 +2019,7 @@ def uniform(a, b, steps = 200):
           var_right  = var.right()
           )
 
-def vonmises(*args, steps = 200):
+def vonmises(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -2056,7 +2038,7 @@ def vonmises(*args, steps = 200):
           var_right  = var.right()
           )
 
-def vonmises_line(*args, steps = 200):
+def vonmises_line(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -2075,7 +2057,7 @@ def vonmises_line(*args, steps = 200):
           var_right  = var.right()
           )
 
-def wald(*args, steps = 200):
+def wald(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -2094,7 +2076,7 @@ def wald(*args, steps = 200):
           var_right  = var.right()
           )
 
-def weibull_min(*args, steps = 200):
+def weibull_min(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -2113,7 +2095,7 @@ def weibull_min(*args, steps = 200):
           var_right  = var.right()
           )
 
-def weibull_max(*args, steps = 200):
+def weibull_max(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -2132,7 +2114,7 @@ def weibull_max(*args, steps = 200):
           var_right  = var.right()
           )
 
-def wrapcauchy(*args, steps = 200):
+def wrapcauchy(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -2151,7 +2133,7 @@ def wrapcauchy(*args, steps = 200):
           var_right  = var.right()
           )
 
-def bernoulli(*args, steps = 200):
+def bernoulli(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -2170,7 +2152,7 @@ def bernoulli(*args, steps = 200):
           var_right  = var.right()
           )
 
-def betabinom(*args, steps = 200):
+def betabinom(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -2189,7 +2171,7 @@ def betabinom(*args, steps = 200):
           var_right  = var.right()
           )
 
-def binom(*args, steps = 200):
+def binom(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -2208,7 +2190,7 @@ def binom(*args, steps = 200):
           var_right  = var.right()
           )
 
-def boltzmann(*args, steps = 200):
+def boltzmann(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -2227,7 +2209,7 @@ def boltzmann(*args, steps = 200):
           var_right  = var.right()
           )
 
-def dlaplace(*args, steps = 200):
+def dlaplace(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -2246,7 +2228,7 @@ def dlaplace(*args, steps = 200):
           var_right  = var.right()
           )
 
-def geom(*args, steps = 200):
+def geom(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -2265,7 +2247,7 @@ def geom(*args, steps = 200):
           var_right  = var.right()
           )
 
-def hypergeom(*args, steps = 200):
+def hypergeom(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -2284,7 +2266,7 @@ def hypergeom(*args, steps = 200):
           var_right  = var.right()
           )
 
-def logser(*args, steps = 200):
+def logser(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -2303,7 +2285,7 @@ def logser(*args, steps = 200):
           var_right  = var.right()
           )
 
-def nbinom(*args, steps = 200):
+def nbinom(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -2322,7 +2304,7 @@ def nbinom(*args, steps = 200):
           var_right  = var.right()
           )
 
-def planck(*args, steps = 200):
+def planck(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -2341,7 +2323,7 @@ def planck(*args, steps = 200):
           var_right  = var.right()
           )
 
-def poisson(*args, steps = 200):
+def poisson(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -2360,7 +2342,7 @@ def poisson(*args, steps = 200):
           var_right  = var.right()
           )
 
-def randint(*args, steps = 200):
+def randint(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -2379,7 +2361,7 @@ def randint(*args, steps = 200):
           var_right  = var.right()
           )
 
-def skellam(*args, steps = 200):
+def skellam(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -2398,7 +2380,7 @@ def skellam(*args, steps = 200):
           var_right  = var.right()
           )
 
-def zipf(*args, steps = 200):
+def zipf(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -2417,7 +2399,7 @@ def zipf(*args, steps = 200):
           var_right  = var.right()
           )
 
-def yulesimon(*args, steps = 200):
+def yulesimon(*args, steps = Pbox.STEPS):
     args = list(args)
     for i in range(0,len(args)):
         if args[i].__class__.__name__ != 'Interval':
@@ -2438,14 +2420,14 @@ def yulesimon(*args, steps = 200):
 
 
 ### Other distributions
-def KM(k,m,steps = 200):
+def KM(k,m,steps = Pbox.STEPS):
     return beta(Interval(k,k+1),Interval(m,m+1),steps = steps)
 
-def KN(k,n,steps = 200):
+def KN(k,n,steps = Pbox.STEPS):
     return KM(k,n-k,steps=steps)
 
 
-### Alternate names
+### Aliases
 normal = norm
 N = normal
 unif = uniform
