@@ -6,15 +6,36 @@ import random as r
 from .logic import Logical
 
 class Interval():
+    """
+    Interval
+    ---------
+    An interval is an uncertain number for which only the endpoints are known, for example if :math:`x=[a,b]`
+    then this can be interpreted as :math:`x` being between :math:`a` and :math:`b` but with no more information about the value of :math:`x`
+    .
 
-    def __repr__(self): # return
-        return "[%g, %g]"%(self.Left,self.Right)
+    Intervals can be created using::
 
-    def __str__(self): # print
-        return "[%g, %g]"%(self.Left,self.Right)
+        pba.I(left,right)
+        pba.Interval(left,right)
 
+    Parameters
+    ----------
+    left : numeric
+        Left side of interval
+    right : numeric
+        Right side of interval
+
+    Attributes
+    ----------
+    Left : numeric
+        Left side of interval
+    Right : numeric
+        Right side of interval
+    
+    """
     def __init__(self,Left = None, Right = None):
 
+
         # kill complex nums
         assert not isinstance(Left, np.complex) or not isinstance(Right, np.complex), "Inputs must be real numbers"
 
@@ -64,6 +85,12 @@ class Interval():
         self.Left = Left
         self.Right = Right
 
+    def __repr__(self): # return
+        return "[%g, %g]"%(self.Left,self.Right)
+
+    def __str__(self): # print
+        return "[%g, %g]"%(self.Left,self.Right)
+
     def __iter__(self):
         for bound in [self.Left, self.Right]:
             yield bound
@@ -376,106 +403,37 @@ class Interval():
             raise ValueError("Truth value of Interval %s is ambiguous" %self)
 
     def left(self):
+        """
+        Returns the left side of the interval
+        """
         return self.Left
 
     def right(self):
+        """
+        Returns the right side of the interval
+        """
         return self.Right
 
     lo = left
     hi = right
 
-    def mean(*args):
-        LSum = 0
-        USum = 0
-        DataLen = len(args)
-        for x in args:
-            if x.__class__.__name__ in ("int","float"):
-                x = Interval(x)
-            if x.__class__.__name__ in ("list","tuple"):
-                DataLen = DataLen + (len(x) - 1)
-                for y in x:
-                    if y.__class__.__name__ in ("int","float"):
-                        y = Interval(y)
-                    LSum = LSum + y.Left
-                    USum = USum + y.Right
-            if x.__class__.__name__ == "Interval":
-                LSum = LSum + x.Left
-                USum = USum + x.Right
-            LMean = LSum / DataLen
-            UMean = USum / DataLen
-        return Interval(LMean, UMean)
-
-    def median(*args):
-        LBounds = []
-        LSorted = []
-        UBounds = []
-        USorted = []
-
-        for x in [*args]:
-            if x.__class__.__name__ in ("int","float"):
-                x = Interval(x)
-                LBounds.append(x.Left)
-                UBounds.append(x.Right)
-            if x.__class__.__name__ in ("list","tuple"):
-                for y in x:
-                    if y.__class__.__name__ in ("int","float"):
-                        y = Interval(y)
-                    LBounds.append(y.Left)
-                    UBounds.append(y.Right)
-            if x.__class__.__name__ == "Interval":
-                LBounds.append(x.Left)
-                UBounds.append(x.Right)
-        while (len(LBounds) > 0):
-            MinL = min(LBounds)
-            LSorted.append(MinL)
-            LBounds.remove(MinL)
-        while (len(UBounds) > 0):
-            MinU = min(UBounds)
-            USorted.append(MinU)
-            UBounds.remove(MinU)
-
-        if (len(LSorted) % 2) != 0:
-            LMedian = LSorted[len(LSorted)//2]
-            UMedian = USorted[len(USorted)//2]
-        else:
-            LMedian = (LSorted[len(LSorted)//2] + LSorted[(len(LSorted)//2)-1])/2
-            UMedian = (USorted[len(USorted)//2] + USorted[(len(USorted)//2)-1])/2
-        return Interval(LMedian,UMedian)
-
-    def variance(*args):
-        dataMean = Interval.mean(*args)
-        LBounds = []
-        UBounds = []
-        LDev = []
-        UDev = []
-        DataLen = len(args)
-        for x in [*args]:
-            if x.__class__.__name__ in ("int","float"):
-                x = Interval(x)
-                LBounds.append(x.Left)
-                UBounds.append(x.Right)
-            if x.__class__.__name__ in ("list","tuple"):
-                DataLen = DataLen + (len(x) - 1)
-                for y in x:
-                    if y.__class__.__name__ in ("int","float"):
-                        y = Interval(y)
-                    LBounds.append(y.Left)
-                    UBounds.append(y.Right)
-
-        for y in LBounds:
-            LDev.append(abs(y - dataMean.Left)**2)
-        for z in UBounds:
-            UDev.append(abs(z - dataMean.Right)**2)
-
-        LSDev = (sum(LDev))/DataLen
-        USDev = (sum(UDev))/DataLen
-        return Interval(LSDev, USDev)
-
-    def mode(*args):
-        NotImplemented
-
     def straddles(self,N, endpoints = True):
+        """
+        Parameters
+        ----------
+        N : numeric
+            Number to check
+        endpoints : bool
+            Whether to include the endpoints within the check
+        
+        Returns
+        -------
+        True
+            If :math:`\\mathrm{left} \\leq N \\leq \mathrm{right}` (Assuming `endpoints=True`)
+        False
+            Otherwise
 
+        """
         if endpoints:
             if self.Left <= N and self.Right >= N:
                 return True
@@ -486,10 +444,18 @@ class Interval():
         return False
 
     def straddles_zero(self,endpoints = True):
+        """
+        Checks whether :math:`0` is within the interval
+        """        
         return self.straddles(0,endpoints)
 
     def recip(self):
+        """
+        Calculates the reciprocle of the interval. 
 
+        If :math:`0 \\in [a,b]` it returns a division by zero error
+        
+        """
         if self.straddles_zero():
             # Cant divide by zero
             raise ZeroDivisionError()
@@ -500,6 +466,9 @@ class Interval():
             return Interval(1/self.lo(), 1/self.hi())
 
     def intersection(self, other):
+        '''
+        Calculates the intersection between two intervals
+        '''
         if isinstance(other, Interval):
             if self.straddles(other):
                 return I(max([x.Left for x in [self, other]]), min([x.Right for x in [self, other]]))
